==> appslandia-common-2.2-sources.jar: com/appslandia/common/base/LruCache.java <==
// The MIT License (MIT)
// Copyright © 2015 AppsLandia. All rights reserved.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package com.appslandia.common.base;

import java.io.Serializable;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 *
 * @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
 *
 */
public class LruCache<K, V> implements Serializable {
	private static final long serialVersionUID = 1L;

	final Mutex mutex = new Mutex();
	final Map<K, V> cache;

	public LruCache(final int cacheSize) {
		this.cache = new LinkedHashMap<K, V>() {
			private static final long serialVersionUID = 1L;

			@Override
			protected boolean removeEldestEntry(Map.Entry<K, V> eldest) {
				return this.size() > cacheSize;
			}
		};
	}

	public void put(K k, V v) {
		synchronized (this.mutex) {
			this.cache.put(k, v);
		}
	}

	public boolean contains(K k) {
		synchronized (this.mutex) {
			return this.cache.containsKey(k);
		}
	}

	public V remove(K k) {
		synchronized (this.mutex) {
			return this.cache.remove(k);
		}
	}

	public V get(K k) {
		synchronized (this.mutex) {
			return this.cache.get(k);
		}
	}
}

==> appslandia-common-7.2-sources.jar: com/appslandia/common/base/LruCache.java <==
// The MIT License (MIT)
// Copyright © 2015 AppsLandia. All rights reserved.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package com.appslandia.common.base;

import java.io.Serializable;
import java.util.Map;

/**
 *
 * @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
 *
 */
public class LruCache<K, V> implements Serializable {
	private static final long serialVersionUID = 1L;

	final Mutex mutex = new Mutex();
	final Map<K, V> cache;

	public LruCache(final int cacheSize) {
		this.cache = new LruMap<K, V>(cacheSize);
	}

	public void put(K k, V v) {
		synchronized (this.mutex) {
			this.cache.put(k, v);
		}
	}

	public boolean contains(K k) {
		synchronized (this.mutex) {
			return this.cache.containsKey(k);
		}
	}

	public V remove(K k) {
		synchronized (this.mutex) {
			return this.cache.remove(k);
		}
	}

	public V get(K k) {
		synchronized (this.mutex) {
			return this.cache.get(k);
		}
	}
}
